@@ -24,22 +24,27 @@ class Smarty_Internal_Method_ClearCache
      * @api  Smarty::clearCache()
      * @link http://www.smarty.net/docs/en/api.clear.cache.tpl
      *
-     * @param \Smarty  $smarty
-     * @param  string  $template_name template name
-     * @param  string  $cache_id      cache id
-     * @param  string  $compile_id    compile id
-     * @param  integer $exp_time      expiration time
-     * @param  string  $type          resource type
+     * @param \Smarty $smarty
+     * @param string  $template_name template name
+     * @param string  $cache_id      cache id
+     * @param string  $compile_id    compile id
+     * @param integer $exp_time      expiration time
+     * @param string  $type          resource type
      *
      * @return int number of cache files deleted
      * @throws \SmartyException
      */
-    public function clearCache(Smarty $smarty, $template_name, $cache_id = null, $compile_id = null, $exp_time = null,
-                               $type = null)
-    {
+    public function clearCache(
+        Smarty $smarty,
+        $template_name,
+        $cache_id = null,
+        $compile_id = null,
+        $exp_time = null,
+        $type = null
+    ) {
         $smarty->_clearTemplateCache();
         // load cache resource and call clear
         $_cache_resource = Smarty_CacheResource::load($smarty, $type);
         return $_cache_resource->clear($smarty, $template_name, $cache_id, $compile_id, $exp_time);
     }
-}
\ No newline at end of file
+}
